# Copyright (c) 2009 gocept gmbh & co. kg
# See also LICENSE.txt

import unittest
import gocept.directory.interfaces
import gocept.directory.resourcegroup
import gocept.directory.nodes
import zope.app.testing.functional
import zope.component


class ResourceGroupTests(zope.app.testing.functional.FunctionalTestCase):

    layer = gocept.directory.testing.DataLayer

    def setUp(self):
        super(ResourceGroupTests, self).setUp()
        self.directory = self.getRootFolder()['directory']
        self.oldsite = zope.app.component.hooks.getSite()
        zope.app.component.hooks.setSite(self.directory)
        self.directory['rg'] = self.rg = \
                gocept.directory.resourcegroup.ResourceGroup('rg')

    def tearDown(self):
        zope.app.component.hooks.setSite(self.oldsite)
        super(ResourceGroupTests, self).tearDown()

    def test_suggest_on_unnamed_resourcegroup(self):
        self.assertEquals(gocept.directory.resourcegroup.ResourceGroup().
                          suggest_hostname(),
                          '')

    def test_suggest_first(self):
        self.assertEquals(self.rg.suggest_hostname(), 'rg00')

    def test_suggest_second(self):
        self.rg['rg00'] = gocept.directory.nodes.Node('rg00')
        self.assertEquals(self.rg.suggest_hostname(), 'rg01')

    def test_suggest_onehundretandone(self):
        for i in range(100):
            nodename = 'rg%02d' % i
            self.rg[nodename] = gocept.directory.nodes.Node(nodename)
        self.assertEquals(self.rg.suggest_hostname(), 'rg100')

    def test_suggest_uses_nodename_not_nodeid(self):
        self.rg['wrong_id'] = gocept.directory.nodes.Node('rg00')
        self.assertEquals(self.rg.suggest_hostname(), 'rg01')

    def test_resourcegroup_is_local_utility(self):
        self.directory['rg-utility'] = \
                gocept.directory.resourcegroup.ResourceGroup('rg-utility')
        rg = zope.component.getUtility(
                gocept.directory.interfaces.IResourceGroup, name='rg-utility')
        self.assertEquals(rg.name, 'rg-utility')


def test_suite():
    return unittest.makeSuite(ResourceGroupTests)
